/****************************************************************************
** Meta object code from reading C++ file 'Auth.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-login-manager-6.7.0/src/auth/Auth.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Auth.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PLASMALOGIN4AuthE_t {};
} // unnamed namespace

template <> constexpr inline auto PLASMALOGIN::Auth::qt_create_metaobjectdata<qt_meta_tag_ZN11PLASMALOGIN4AuthE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PLASMALOGIN::Auth",
        "autologinChanged",
        "",
        "greeterChanged",
        "verboseChanged",
        "userChanged",
        "displayServerCommandChanged",
        "sessionChanged",
        "requestChanged",
        "authentication",
        "user",
        "success",
        "sessionStarted",
        "displayServerReady",
        "displayName",
        "finished",
        "Auth::HelperExitStatus",
        "status",
        "error",
        "message",
        "Auth::Error",
        "type",
        "info",
        "Auth::Info",
        "start",
        "stop",
        "Info",
        "INFO_NONE",
        "INFO_UNKNOWN",
        "INFO_PASS_CHANGE_REQUIRED",
        "_INFO_LAST",
        "Error",
        "ERROR_NONE",
        "ERROR_UNKNOWN",
        "ERROR_AUTHENTICATION",
        "ERROR_INTERNAL",
        "_ERROR_LAST",
        "HelperExitStatus",
        "HELPER_SUCCESS",
        "HELPER_AUTH_ERROR",
        "HELPER_SESSION_ERROR",
        "HELPER_OTHER_ERROR",
        "HELPER_DISPLAYSERVER_ERROR",
        "HELPER_TTY_ERROR"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'autologinChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'greeterChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verboseChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayServerCommandChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sessionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authentication'
        QtMocHelpers::SignalData<void(QString, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'sessionStarted'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'displayServerReady'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(Auth::HelperExitStatus)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(QString, Auth::Error)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Signal 'info'
        QtMocHelpers::SignalData<void(QString, Auth::Info)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { 0x80000000 | 23, 21 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Info'
        QtMocHelpers::EnumData<enum Info>(26, 26, QMC::EnumFlags{}).add({
            {   27, Info::INFO_NONE },
            {   28, Info::INFO_UNKNOWN },
            {   29, Info::INFO_PASS_CHANGE_REQUIRED },
            {   30, Info::_INFO_LAST },
        }),
        // enum 'Error'
        QtMocHelpers::EnumData<enum Error>(31, 31, QMC::EnumFlags{}).add({
            {   32, Error::ERROR_NONE },
            {   33, Error::ERROR_UNKNOWN },
            {   34, Error::ERROR_AUTHENTICATION },
            {   35, Error::ERROR_INTERNAL },
            {   36, Error::_ERROR_LAST },
        }),
        // enum 'HelperExitStatus'
        QtMocHelpers::EnumData<enum HelperExitStatus>(37, 37, QMC::EnumFlags{}).add({
            {   38, HelperExitStatus::HELPER_SUCCESS },
            {   39, HelperExitStatus::HELPER_AUTH_ERROR },
            {   40, HelperExitStatus::HELPER_SESSION_ERROR },
            {   41, HelperExitStatus::HELPER_OTHER_ERROR },
            {   42, HelperExitStatus::HELPER_DISPLAYSERVER_ERROR },
            {   43, HelperExitStatus::HELPER_TTY_ERROR },
        }),
    };
    return QtMocHelpers::metaObjectData<Auth, qt_meta_tag_ZN11PLASMALOGIN4AuthE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PLASMALOGIN::Auth::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN4AuthE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN4AuthE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PLASMALOGIN4AuthE_t>.metaTypes,
    nullptr
} };

void PLASMALOGIN::Auth::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Auth *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->autologinChanged(); break;
        case 1: _t->greeterChanged(); break;
        case 2: _t->verboseChanged(); break;
        case 3: _t->userChanged(); break;
        case 4: _t->displayServerCommandChanged(); break;
        case 5: _t->sessionChanged(); break;
        case 6: _t->requestChanged(); break;
        case 7: _t->authentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->sessionStarted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->displayServerReady((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->finished((*reinterpret_cast<std::add_pointer_t<Auth::HelperExitStatus>>(_a[1]))); break;
        case 11: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Auth::Error>>(_a[2]))); break;
        case 12: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Auth::Info>>(_a[2]))); break;
        case 13: _t->start(); break;
        case 14: _t->stop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Auth::*)()>(_a, &Auth::autologinChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)()>(_a, &Auth::greeterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)()>(_a, &Auth::verboseChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)()>(_a, &Auth::userChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)()>(_a, &Auth::displayServerCommandChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)()>(_a, &Auth::sessionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)()>(_a, &Auth::requestChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)(QString , bool )>(_a, &Auth::authentication, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)(bool )>(_a, &Auth::sessionStarted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)(const QString & )>(_a, &Auth::displayServerReady, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)(Auth::HelperExitStatus )>(_a, &Auth::finished, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)(QString , Auth::Error )>(_a, &Auth::error, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Auth::*)(QString , Auth::Info )>(_a, &Auth::info, 12))
            return;
    }
}

const QMetaObject *PLASMALOGIN::Auth::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PLASMALOGIN::Auth::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN4AuthE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PLASMALOGIN::Auth::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void PLASMALOGIN::Auth::autologinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PLASMALOGIN::Auth::greeterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PLASMALOGIN::Auth::verboseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PLASMALOGIN::Auth::userChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PLASMALOGIN::Auth::displayServerCommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PLASMALOGIN::Auth::sessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PLASMALOGIN::Auth::requestChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PLASMALOGIN::Auth::authentication(QString _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void PLASMALOGIN::Auth::sessionStarted(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void PLASMALOGIN::Auth::displayServerReady(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PLASMALOGIN::Auth::finished(Auth::HelperExitStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PLASMALOGIN::Auth::error(QString _t1, Auth::Error _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void PLASMALOGIN::Auth::info(QString _t1, Auth::Info _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}
QT_WARNING_POP
