/****************************************************************************
** Meta object code from reading C++ file 'kcm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-login-manager-6.7.0/src/frontend/kcm/kcm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14PlasmaLoginKcmE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaLoginKcm::qt_create_metaobjectdata<qt_meta_tag_ZN14PlasmaLoginKcmE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaLoginKcm",
        "errorOccurred",
        "",
        "untranslatedMessage",
        "syncAttempted",
        "defaultsCalled",
        "isDefaultsWallpaperChanged",
        "currentWallpaperChanged",
        "loadCalled",
        "load",
        "save",
        "defaults",
        "updateState",
        "forceUpdateState",
        "availableWallpaperPlugins",
        "QList<WallpaperInfo>",
        "synchronizeSettings",
        "resetSynchronizedSettings",
        "KDEWalletAvailable",
        "openKDEWallet",
        "settings",
        "PlasmaLoginSettings*",
        "wallpaperConfiguration",
        "KConfigPropertyMap*",
        "wallpaperConfigFile",
        "QUrl",
        "wallpaperIntegration",
        "WallpaperIntegration*",
        "currentWallpaper",
        "isDefaultsWallpaper",
        "userModel",
        "UserModel*",
        "sessionModel",
        "SessionModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'syncAttempted'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultsCalled'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDefaultsWallpaperChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentWallpaperChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadCalled'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateState'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceUpdateState'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'availableWallpaperPlugins'
        QtMocHelpers::MethodData<QList<WallpaperInfo>()>(14, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Method 'synchronizeSettings'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'resetSynchronizedSettings'
        QtMocHelpers::MethodData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'KDEWalletAvailable'
        QtMocHelpers::MethodData<bool()>(18, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'openKDEWallet'
        QtMocHelpers::MethodData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'settings'
        QtMocHelpers::PropertyData<PlasmaLoginSettings*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'wallpaperConfiguration'
        QtMocHelpers::PropertyData<KConfigPropertyMap*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'wallpaperConfigFile'
        QtMocHelpers::PropertyData<QUrl>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'wallpaperIntegration'
        QtMocHelpers::PropertyData<WallpaperIntegration*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'currentWallpaper'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'isDefaultsWallpaper'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'userModel'
        QtMocHelpers::PropertyData<UserModel*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sessionModel'
        QtMocHelpers::PropertyData<SessionModel*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmaLoginKcm, qt_meta_tag_ZN14PlasmaLoginKcmE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlasmaLoginKcm::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PlasmaLoginKcmE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PlasmaLoginKcmE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14PlasmaLoginKcmE_t>.metaTypes,
    nullptr
} };

void PlasmaLoginKcm::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaLoginKcm *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->syncAttempted(); break;
        case 2: _t->defaultsCalled(); break;
        case 3: _t->isDefaultsWallpaperChanged(); break;
        case 4: _t->currentWallpaperChanged(); break;
        case 5: _t->loadCalled(); break;
        case 6: _t->load(); break;
        case 7: _t->save(); break;
        case 8: _t->defaults(); break;
        case 9: _t->updateState(); break;
        case 10: _t->forceUpdateState(); break;
        case 11: { QList<WallpaperInfo> _r = _t->availableWallpaperPlugins();
            if (_a[0]) *reinterpret_cast<QList<WallpaperInfo>*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->synchronizeSettings(); break;
        case 13: _t->resetSynchronizedSettings(); break;
        case 14: { bool _r = _t->KDEWalletAvailable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->openKDEWallet(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaLoginKcm::*)(const QString & )>(_a, &PlasmaLoginKcm::errorOccurred, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaLoginKcm::*)()>(_a, &PlasmaLoginKcm::syncAttempted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaLoginKcm::*)()>(_a, &PlasmaLoginKcm::defaultsCalled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaLoginKcm::*)()>(_a, &PlasmaLoginKcm::isDefaultsWallpaperChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaLoginKcm::*)()>(_a, &PlasmaLoginKcm::currentWallpaperChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaLoginKcm::*)()>(_a, &PlasmaLoginKcm::loadCalled, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KConfigPropertyMap* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PlasmaLoginSettings* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< WallpaperIntegration* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<PlasmaLoginSettings**>(_v) = _t->settings(); break;
        case 1: *reinterpret_cast<KConfigPropertyMap**>(_v) = _t->wallpaperConfiguration(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->wallpaperConfigFile(); break;
        case 3: *reinterpret_cast<WallpaperIntegration**>(_v) = _t->wallpaperIntegration(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->currentWallpaper(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isDefaultsWallpaper(); break;
        case 6: *reinterpret_cast<UserModel**>(_v) = _t->userModel(); break;
        case 7: *reinterpret_cast<SessionModel**>(_v) = _t->sessionModel(); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaLoginKcm::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaLoginKcm::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PlasmaLoginKcmE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int PlasmaLoginKcm::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PlasmaLoginKcm::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlasmaLoginKcm::syncAttempted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlasmaLoginKcm::defaultsCalled()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlasmaLoginKcm::isDefaultsWallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlasmaLoginKcm::currentWallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PlasmaLoginKcm::loadCalled()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
