/****************************************************************************
** Meta object code from reading C++ file 'Greeter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-login-manager-6.7.0/src/daemon/Greeter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Greeter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PLASMALOGIN7GreeterE_t {};
} // unnamed namespace

template <> constexpr inline auto PLASMALOGIN::Greeter::qt_create_metaobjectdata<qt_meta_tag_ZN11PLASMALOGIN7GreeterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PLASMALOGIN::Greeter",
        "ttyFailed",
        "",
        "failed",
        "displayServerFailed",
        "start",
        "stop",
        "finished",
        "onRequestChanged",
        "onSessionStarted",
        "success",
        "onHelperFinished",
        "Auth::HelperExitStatus",
        "status",
        "onReadyReadStandardOutput",
        "onReadyReadStandardError",
        "authInfo",
        "message",
        "Auth::Info",
        "info",
        "authError",
        "Auth::Error",
        "error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ttyFailed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayServerFailed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<bool()>(5, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finished'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onRequestChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSessionStarted'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'onHelperFinished'
        QtMocHelpers::SlotData<void(Auth::HelperExitStatus)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'onReadyReadStandardOutput'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onReadyReadStandardError'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'authInfo'
        QtMocHelpers::SlotData<void(const QString &, Auth::Info)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Slot 'authError'
        QtMocHelpers::SlotData<void(const QString &, Auth::Error)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { 0x80000000 | 21, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Greeter, qt_meta_tag_ZN11PLASMALOGIN7GreeterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PLASMALOGIN::Greeter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN7GreeterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN7GreeterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PLASMALOGIN7GreeterE_t>.metaTypes,
    nullptr
} };

void PLASMALOGIN::Greeter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Greeter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ttyFailed(); break;
        case 1: _t->failed(); break;
        case 2: _t->displayServerFailed(); break;
        case 3: { bool _r = _t->start();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->stop(); break;
        case 5: _t->finished(); break;
        case 6: _t->onRequestChanged(); break;
        case 7: _t->onSessionStarted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->onHelperFinished((*reinterpret_cast<std::add_pointer_t<Auth::HelperExitStatus>>(_a[1]))); break;
        case 9: _t->onReadyReadStandardOutput(); break;
        case 10: _t->onReadyReadStandardError(); break;
        case 11: _t->authInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Auth::Info>>(_a[2]))); break;
        case 12: _t->authError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Auth::Error>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Greeter::*)()>(_a, &Greeter::ttyFailed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greeter::*)()>(_a, &Greeter::failed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greeter::*)()>(_a, &Greeter::displayServerFailed, 2))
            return;
    }
}

const QMetaObject *PLASMALOGIN::Greeter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PLASMALOGIN::Greeter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN7GreeterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PLASMALOGIN::Greeter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void PLASMALOGIN::Greeter::ttyFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PLASMALOGIN::Greeter::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PLASMALOGIN::Greeter::displayServerFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
