/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.DisplayManager.Session.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SESSIONADAPTOR_H
#define SESSIONADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "DisplayManager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.DisplayManager.Session
 */
class SessionAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.DisplayManager.Session")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.DisplayManager.Session\">\n"
"    <method name=\"Lock\"/>\n"
"    <property access=\"read\" type=\"o\" name=\"Seat\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"UserName\"/>\n"
"  </interface>\n"
        "")
public:
    SessionAdaptor(PLASMALOGIN::DisplayManagerSession *parent);
    ~SessionAdaptor() override;

    inline PLASMALOGIN::DisplayManagerSession *parent() const
    { return static_cast<PLASMALOGIN::DisplayManagerSession *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QDBusObjectPath Seat READ seat)
    QDBusObjectPath seat() const;

    Q_PROPERTY(QString UserName READ userName)
    QString userName() const;

public Q_SLOTS: // METHODS
    void Lock();
Q_SIGNALS: // SIGNALS
};

#endif
