/****************************************************************************
** Meta object code from reading C++ file 'HelperApp.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-login-manager-6.7.0/src/helper/HelperApp.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'HelperApp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PLASMALOGIN9HelperAppE_t {};
} // unnamed namespace

template <> constexpr inline auto PLASMALOGIN::HelperApp::qt_create_metaobjectdata<qt_meta_tag_ZN11PLASMALOGIN9HelperAppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PLASMALOGIN::HelperApp",
        "request",
        "Request",
        "",
        "info",
        "message",
        "Auth::Info",
        "type",
        "error",
        "Auth::Error",
        "authenticated",
        "QProcessEnvironment",
        "user",
        "displayServerStarted",
        "displayName",
        "sessionOpened",
        "success",
        "setUp",
        "doAuth",
        "sessionFinished",
        "status"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'request'
        QtMocHelpers::SlotData<Request(const Request &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 1 },
        }}),
        // Slot 'info'
        QtMocHelpers::SlotData<void(const QString &, Auth::Info)>(4, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'error'
        QtMocHelpers::SlotData<void(const QString &, Auth::Error)>(8, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 9, 7 },
        }}),
        // Slot 'authenticated'
        QtMocHelpers::SlotData<QProcessEnvironment(const QString &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'displayServerStarted'
        QtMocHelpers::SlotData<void(const QString &)>(13, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'sessionOpened'
        QtMocHelpers::SlotData<void(bool)>(15, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'setUp'
        QtMocHelpers::SlotData<void()>(17, 3, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doAuth'
        QtMocHelpers::SlotData<void()>(18, 3, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sessionFinished'
        QtMocHelpers::SlotData<void(int)>(19, 3, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HelperApp, qt_meta_tag_ZN11PLASMALOGIN9HelperAppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PLASMALOGIN::HelperApp::staticMetaObject = { {
    QMetaObject::SuperData::link<QCoreApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN9HelperAppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN9HelperAppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PLASMALOGIN9HelperAppE_t>.metaTypes,
    nullptr
} };

void PLASMALOGIN::HelperApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HelperApp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Request _r = _t->request((*reinterpret_cast<std::add_pointer_t<Request>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Request*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Auth::Info>>(_a[2]))); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Auth::Error>>(_a[2]))); break;
        case 3: { QProcessEnvironment _r = _t->authenticated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QProcessEnvironment*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->displayServerStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->sessionOpened((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setUp(); break;
        case 7: _t->doAuth(); break;
        case 8: _t->sessionFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PLASMALOGIN::HelperApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PLASMALOGIN::HelperApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PLASMALOGIN9HelperAppE_t>.strings))
        return static_cast<void*>(this);
    return QCoreApplication::qt_metacast(_clname);
}

int PLASMALOGIN::HelperApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCoreApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
