// This file is generated by kconfig_compiler_kf6 from mainconfig.kcfg.
// All changes you do to this file will be lost.

#include "mainconfig.h"

MainConfig::MainConfig( std::unique_ptr<KConfig> config )
  : KConfigSkeleton(std::move(config), KCoreConfigSkeleton::DisambiguateConstructor::IsStdUniqPtr)
{
  setCurrentGroup( QStringLiteral( "X11" ) );

  KConfigSkeleton::ItemString  *itemX11ServerPath;
  itemX11ServerPath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ServerPath" ), mX11ServerPath, QStringLiteral( "/usr/bin/X" ) );
  addItem( itemX11ServerPath, QStringLiteral( "X11ServerPath" ) );
  KConfigSkeleton::ItemString  *itemX11ServerArguments;
  itemX11ServerArguments = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ServerArguments" ), mX11ServerArguments, QStringLiteral( "-nolisten tcp" ) );
  addItem( itemX11ServerArguments, QStringLiteral( "X11ServerArguments" ) );
  KConfigSkeleton::ItemString  *itemX11SessionLogFile;
  itemX11SessionLogFile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SessionLogFile" ), mX11SessionLogFile, QStringLiteral( ".local/share/plasmalogin/xorg-session.log" ) );
  addItem( itemX11SessionLogFile, QStringLiteral( "X11SessionLogFile" ) );

  setCurrentGroup( QStringLiteral( "Wayland" ) );

  KConfigSkeleton::ItemString  *itemWaylandSessionLogFile;
  itemWaylandSessionLogFile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SessionLogFile" ), mWaylandSessionLogFile, QStringLiteral( ".local/share/plasmalogin/wayland-session.log" ) );
  addItem( itemWaylandSessionLogFile, QStringLiteral( "WaylandSessionLogFile" ) );

  setCurrentGroup( QStringLiteral( "Autologin" ) );

  KConfigSkeleton::ItemString  *itemAutologinUser;
  itemAutologinUser = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "User" ), mAutologinUser );
  addItem( itemAutologinUser, QStringLiteral( "AutologinUser" ) );
  KConfigSkeleton::ItemString  *itemAutologinSession;
  itemAutologinSession = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Session" ), mAutologinSession );
  addItem( itemAutologinSession, QStringLiteral( "AutologinSession" ) );
  KConfigSkeleton::ItemBool  *itemAutologinRelogin;
  itemAutologinRelogin = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Relogin" ), mAutologinRelogin, false );
  addItem( itemAutologinRelogin, QStringLiteral( "AutologinRelogin" ) );

  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemStringList  *itemNamespaces;
  itemNamespaces = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "Namespaces" ), mNamespaces );
  addItem( itemNamespaces, QStringLiteral( "Namespaces" ) );

  setCurrentGroup( QStringLiteral( "Users" ) );

  KConfigSkeleton::ItemString  *itemDefaultPath;
  itemDefaultPath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultPath" ), mDefaultPath, QStringLiteral( "/usr/local/bin:/usr/bin:/bin" ) );
  addItem( itemDefaultPath, QStringLiteral( "DefaultPath" ) );
}

MainConfig::~MainConfig()
{
}

